@@ -19,16 +19,27 @@ test_that("Verify the input data for mapping", {
   data("sdgstat")
   df <- sdgstat[1:3]
 
-  expect_message(
-    plot_sdg_map(
-      data = df,
-      sdg = "SDG",
-      value = "Value",
-      country = "Country",
-      by_sdg = F
-    ),
-    "The input data must contain a minimum of three columns, including SDG name, numeric value, and geographic location."
-  )
+  # expect_message(
+  #   plot_sdg_map(
+  #     data = df,
+  #     sdg = "SDG",
+  #     value = "Value",
+  #     country = "Country",
+  #     by_sdg = F
+  #   ),
+  #   "The input data must contain a minimum of three columns, including SDG name, numeric value, and geographic location."
+  # )
+
+
+  expect_error(
+      plot_sdg_map(
+        data = df,
+        sdg = "SDG",
+        value = "Value",
+        country = "Country",
+        by_sdg = F),
+    "Data object must include columns [Country].", fixed=TRUE)
+
 })
 
 
